DeviceSamplingPackage class

Inheritance

Constructors

DeviceSamplingPackage()

Properties

dataTypes → List<String>
The list of data type this package supports.
no setteroverride
deviceManager → DeviceManager<DeviceRegistration, DeviceDescriptor>
Get the DeviceManager for the device used by this package.
no setterinherited
deviceType → String
What device type is this package using?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
permissions → List<Permission>
The list of permissions that this package need.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingSchema → SamplingSchema
Default samplings schema for:
no setteroverride

Methods

create(String type) → Probe?
Creates a new Probe of the specified type. Returns null if a probe cannot be created for this type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegister() → void
Callback method when this package is being registered.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

BATTERY → const String
Measure type for collection of battery level and charging status.
DEVICE → const String
Measure type for collection of basic device information like device name, model, manufacturer, operating system, and hardware profile.
MEMORY → const String
Measure type for collection of free physical and virtual memory.
SCREEN → const String
Measure type for collection of screen events (on/off/unlocked).
TIMEZONE → const String
Measure type for collection of the time zone of the device. See List of tz database time zones for an overview of timezones.