AppLifecycleTrigger class

A trigger that triggers when the life cycle of an app changes.

The state changes that triggers are specified in states. If not specified (default) this trigger will trigger on all AppLifecycleState changes.

Typically used to make sure to collect measures when the app life cycle is changing, e.g., moved to the background or foreground. Some measures - like audio, bluetooth, and health - can only be collected when the app is in the foreground.

Inheritance
  • Object
  • Serializable
  • TriggerConfiguration
  • AppLifecycleTrigger
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

AppLifecycleTrigger([Set<AppLifecycleState>? states])
Create a AppLifecycleTrigger that triggers whenever the app state changes. If states is not specified, it will trigger on all state change events.
AppLifecycleTrigger.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
requiresPrimaryDevice bool?
Determines whether the trigger needs to be evaluated on a primary device (PrimaryDeviceConfiguration). For example, this is the case when the trigger is time bound and needs to be evaluated by a task scheduler running on a primary device.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceDeviceRoleName String?
The device role name from which the trigger originates.
getter/setter pairinherited
states Set<AppLifecycleState>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited