allowDuplicates property
Whether to receive repeated scan results for the same device. Useful for RSSI updates.
Implementation
bool allowDuplicates = true;
Whether to receive repeated scan results for the same device. Useful for RSSI updates.
bool allowDuplicates = true;