CARPTransformerSchema class

A default DataTransformerSchema for CARP no-operation transformers

Inheritance

Constructors

CARPTransformerSchema()

Properties

hashCode → int
The hash code for this object.
no setterinherited
namespace → String
The type of namespace that this package can transform to (see e.g. NameSpace for pre-defined namespaces).
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformers → Map<String, DataTransformer>
A map of transformers in this schema, indexed by the data type they can transform.
no setterinherited

Methods

add(String format, DataTransformer transformer) → void
Add a transformer to this schema that can map data of a specific format.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegister() → void
Callback method when this schema is being registered.
override
toString() → String
A string representation of this object.
inherited
transform(Data data) → Data
Transform the data using a transformer for its data format. If no transformer is found, returns data unchanged.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited