deviceId property

String deviceId
getter/setter pairinherited

An ID for the device, used to disambiguate between devices of the same type, as provided by the device itself. It is up to specific types of devices to guarantee uniqueness across all devices of the same type.

Implementation

late String deviceId;