CompletedAppTask class

Data about a completed AppTask.

taskName is the name of the completed app task. taskType indicates the type of app task completed. completedAt is the time this task was completed (in UTC). taskData holds the result of the task, or null if no result is collected.

Inheritance
  • Object
  • Serializable
  • Data
  • CompletedTask
  • CompletedAppTask
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

CompletedAppTask({required String taskName, required String taskType, Data? taskData})
Create a completed app task with the given taskName and taskType, and optional taskData.
CompletedAppTask.fromJson(Map<String, dynamic> json)
factory
CompletedAppTask.fromUserTask(UserTask userTask)
Create a completed app task based on the given userTask.

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
completedAt DateTime
The time when the task was completed in UTC.
getter/setter pair
dataType → DataType
The type of this data as a DataType.
no setterinherited
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskData ↔ Data?
The result of the completed task, if any.
getter/setter pairinherited
taskName String
The name of the task which was completed. This is the name of the task as specified in the study protocol.
getter/setter pairinherited
taskType String
The type of AppTask which was completed, if specified.
getter/setter pair

Methods

equivalentTo(Data other) bool
Is this data equivalent to other?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited