ConditionalPeriodicTrigger class

A trigger that periodically checks if an application-specific triggering condition is met.

Note that the triggerCondition is a ConditionalEvaluator function, which cannot be serialized to/from JSON. Thus, even though this trigger can be de/serialized from/to JSON, its triggerCondition cannot. This implies that this function cannot be retrieved as part of a StudyProtocol from a DeploymentService since it relies on specifying a Dart-specific function as the ConditionalEvaluator methods. Hence, this trigger is mostly useful when creating a StudyProtocol directly in the app using Dart code.

Inheritance
  • Object
  • Serializable
  • TriggerConfiguration
  • ConditionalPeriodicTrigger
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

ConditionalPeriodicTrigger({required Duration period, ConditionalEvaluator? triggerCondition})
Create a ConditionalSamplingEventTrigger.
ConditionalPeriodicTrigger.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
period ↔ Duration
The period of when to check the triggerCondition.
getter/setter pair
requiresPrimaryDevice ↔ bool?
Determines whether the trigger needs to be evaluated on a primary device (PrimaryDeviceConfiguration). For example, this is the case when the trigger is time bound and needs to be evaluated by a task scheduler running on a primary device.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDeviceRoleName ↔ String?
The device role name from which the trigger originates.
getter/setter pairinherited
triggerCondition ↔ ConditionalEvaluator?
The ConditionalEventEvaluator function evaluating if the event condition is meet for triggering this trigger
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited