ConditionalSamplingEventTrigger class

A trigger that resume and pause sampling when some (other) sampling event occurs and a application-specific condition is meet.

Note that the resumeCondition and pauseCondition are ConditionalEvaluator functions which cannot be serialized to/from JSON. Thus, even though this trigger can be de/serialized from/to JSON, its resumeCondition and pauseCondition cannot. This implies that these functions cannot be retrieved as part of a StudyProtocol from a DeploymentService since it relies on specifying a Dart-specific function as the ConditionalEvaluator methods. Hence, this trigger is mostly useful when creating a StudyProtocol directly in the app using Dart code.

If you need to de/serialize an event trigger, use the SamplingEventTrigger instead.

Inheritance
  • Object
  • Serializable
  • Trigger
  • ConditionalSamplingEventTrigger
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.none, includeIfNull: false)

Constructors

ConditionalSamplingEventTrigger({required String measureType, ConditionalEventEvaluator? resumeCondition, ConditionalEventEvaluator? pauseCondition})
Create a trigger that triggers when a measure of measureType is collected, and checks the resumeCondition and pauseCondition to determine if the task should be resumed or paused, respectively.
ConditionalSamplingEventTrigger.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
measureType ↔ String
The data type of the event to look for.
getter/setter pair
pauseCondition ↔ ConditionalEventEvaluator?
The ConditionalEventEvaluator function evaluating if the event condition is meet for pausing this trigger.
getter/setter pair
requiresMasterDevice ↔ bool?
Determines whether the trigger needs to be evaluated on a master device (MasterDeviceDescriptor). For example, this is the case when the trigger is time bound and needs to be evaluated by a task scheduler running on a master device.
getter/setter pairinherited
resumeCondition ↔ ConditionalEventEvaluator?
The ConditionalEventEvaluator function evaluating if the event condition is meet for resuming this trigger
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDeviceRoleName ↔ String?
The device role name from which the trigger originates.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited