CronScheduledTrigger class

A trigger that triggers based on a cron job specification.

Bases on the cron package. See crontab guru for a useful tool for specifying cron jobs.

Inheritance
  • Object
  • Serializable
  • TriggerConfiguration
  • CronScheduledTrigger
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

CronScheduledTrigger({int? minute, int? hour, int? day, int? month, int? weekday})
Create a cron scheduled trigger based on specifying:
factory
CronScheduledTrigger.fromJson(Map<String, dynamic> json)
factory
CronScheduledTrigger.parse({required String cronExpression, Duration? duration})
Create a CronScheduledTrigger based on a cron-formatted string expression.
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
cronExpression ↔ String
The cron job expression.
getter/setter pair
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
requiresPrimaryDevice ↔ bool?
Determines whether the trigger needs to be evaluated on a primary device (PrimaryDeviceConfiguration). For example, this is the case when the trigger is time bound and needs to be evaluated by a task scheduler running on a primary device.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDeviceRoleName ↔ String?
The device role name from which the trigger originates.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited