DataTransformerSchemaRegistry class

A registry of DataTransformerSchemas which hold a set of DataTransformers.

Constructors

DataTransformerSchemaRegistry()
Get the singleton instance of the DataTransformerSchemaRegistry.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemas → Map<String, DataTransformerSchema>
The map between the namespace of a transformer schema and the schema.
no setter

Methods

lookup(String namespace) → DataTransformerSchema?
Lookup a transformer schema based on its namespace.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(DataTransformerSchema schema) → void
Register a transformer schema.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited