DeviceInfo class

Provides (static) information about the local device.

This class is a singleton that one time access the information from the local device to be used in the sensing framework.

Constructors

DeviceInfo()
factory

Properties

deviceData ↔ Map<String, dynamic>
The device info for this device.
getter/setter pair
deviceID ↔ String?
getter/setter pair
deviceManufacturer ↔ String?
getter/setter pair
deviceModel ↔ String?
getter/setter pair
deviceName ↔ String?
getter/setter pair
hardware ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
operatingSystem ↔ String?
getter/setter pair
platform ↔ String?
getter/setter pair
release ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdk ↔ String?
getter/setter pair

Methods

init() → Future<void>
Initialize the device info using the DeviceInfoPlugin.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited