DeviceInfoService class

Provides (static) information about the local device.

This service works as a singleton that one time access the information from the local device to be used in the sensing framework.

It takes different hardware information from Android and iOS:

Constructors

DeviceInfoService()
factory

Properties

deviceData ↔ Map<String, dynamic>
The full device info for this device. See BaseDeviceInfo.data.
getter/setter pair
deviceID ↔ String?
Unique device ID
getter/setter pair
deviceManufacturer ↔ String?
The manufacturer of the device.
getter/setter pair
deviceModel ↔ String?
Device Model
getter/setter pair
deviceName ↔ String?
Device name.
getter/setter pair
hardware ↔ String?
The name of the hardware.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialized → bool
Has the device info been initialized?
no setter
operatingSystemName ↔ String?
The name of the current operating system.
getter/setter pair
operatingSystemVersion ↔ String?
The current operating system version.
getter/setter pair
platform ↔ String?
Android or iOS
getter/setter pair
release ↔ String?
Release level.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdk ↔ String?
SDK level.
getter/setter pair

Methods

init() → Future<void>
Initialize the device info service using the DeviceInfoPlugin.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited