FileDataEndPoint class

Specify an endpoint where a file-based data manager can store JSON data as files on the local device.

Inheritance
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

FileDataEndPoint({String dataFormat = NameSpace.CARP, int bufferSize = 500 * 1000, bool zip = true, bool encrypt = false, String? publicKey})
Creates a FileDataEndPoint.
FileDataEndPoint.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
bufferSize ↔ int
The buffer size of the raw JSON file in bytes.
getter/setter pair
dataFormat ↔ String
The preferred format of the data to be uploaded according to NameSpace. Default using the NameSpace.CARP.
getter/setter pairinherited
encrypt ↔ bool
Is data to be encrypted before storing. False as default.
getter/setter pair
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
publicKey ↔ String?
If encrypt is true, this should hold the public key in a RSA KPI encryption of data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
The type of endpoint as enumerated in DataEndPointTypes.
getter/setter pairinherited
zip ↔ bool
Is data to be compressed (zipped) before storing in a file. True as default.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited