HardwareDeviceRegistration class
A DeviceRegistration for a hardware device.
- Inheritance
-
- Object
- Serializable
- DeviceRegistration
- CamsDeviceRegistration
- HardwareDeviceRegistration
- Implementers
- Annotations
-
- @JsonSerializable.new(includeIfNull: false, explicitToJson: true)
Constructors
- HardwareDeviceRegistration({String? deviceId, String? deviceDisplayName, DateTime? registrationCreatedOn, bool isConnected = false, BatteryChargingState batteryChargingState = BatteryChargingState.unknown, String? hardwareName})
-
Create a new HardwareDeviceRegistration based on hardware information,
incl
hardwareNameandbatteryChargingState. -
HardwareDeviceRegistration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $type ↔ String?
-
The runtime class name (type) of this object.
Used for deserialization from JSON objects.
getter/setter pairinherited
- batteryChargingState ↔ BatteryChargingState
-
The battery charging state of the device upon registration.
getter/setter pair
- deviceDisplayName ↔ String?
-
An optional concise textual representation for display purposes describing
the key specifications of the device.
E.g., device manufacturer, name, and operating system version.
getter/setter pairinherited
- deviceId ↔ String
-
An ID for the device, used to disambiguate between devices of the same type,
as provided by the device itself.
It is up to specific types of devices to guarantee uniqueness across all
devices of the same type.
getter/setter pairinherited
- fromJsonFunction → Function
-
The function which can convert a JSON string to an object of this type.
no setteroverride
- hardwareName ↔ String?
-
The hardware name of this device, if available.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected ↔ bool
-
Indicates whether this device was connected when registered.
getter/setter pairinherited
- jsonType → String
-
Return the
__typeto be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.no setterinherited - registrationCreatedOn ↔ DateTime
-
The registration time in zulu time.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Return a JSON encoding of this object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parseBatteryLevel(
int batteryLevel) → BatteryChargingState - Get the BatteryChargingState based on a battery level percentage (0-100).