MonitoringSamplingPackage class

A SamplingPackage containing data types, sampling schemas and probes for monitoring data sampling:

  • errors
  • task triggering
  • task completion, including AppTask completion
Inheritance

Constructors

MonitoringSamplingPackage()

Properties

dataTypes → List<DataTypeMetaData>
The list of data type this package supports.
no setterinherited
deviceManager → DeviceManager<DeviceConfiguration<DeviceRegistration>, DeviceRegistration>
Get the DeviceManager for the device used by this package.
no setterinherited
deviceType → String
What device type is this package using?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingSchemes → DataTypeSamplingSchemeMap
The default sampling schemes for all dataTypes in this package.
no setteroverride

Methods

create(String type) → Probe?
Creates a new Probe of the specified type. Note that type should be one of the dataTypes that this package supports. Returns null if a probe cannot be created for the type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegister() → void
Callback method when this package is being registered.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

COMPLETED_APP_TASK → const String
Collect data whenever an AppTask has been completed.
COMPLETED_TASK → const String
Collect data whenever any TaskConfiguration has been completed.
ERROR → const String
Collect errors occurring during data collection
TRIGGERED_TASK → const String
Collect data on a triggered TaskConfiguration.