create method
Creates a new Probe of the specified type.
Note that type should be one of the dataTypes that this package supports.
Returns null if a probe cannot be created for the type.
Implementation
@override
Probe? create(String type) => StubProbe();