OnlineService class

An online service which works as a "software device" in a protocol.

Inheritance
  • Object
  • Serializable
  • DeviceDescriptor
  • OnlineService
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.none, includeIfNull: false)

Constructors

OnlineService({required String roleName, List<String>? supportedDataTypes})
OnlineService.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isMasterDevice ↔ bool?
Is this the master device?
getter/setter pairinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
roleName ↔ String
The role name of this device in a specific StudyProtocol. For example, 'Parent's phone' or 'Child phone'.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingConfiguration ↔ Map<String, SamplingConfiguration>
Sampling configurations for data types available on this device which override the default configuration.
getter/setter pairinherited
supportedDataTypes ↔ List<String>?
The set of data types which can be collected on this device.
getter/setter pairinherited
type → String
The device type identifier
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited