RandomRecurrentTrigger class

A daily trigger that triggers a random number of times within a defined period of time of the day.

The random value is between the minNumberOfTriggers and maxNumberOfTriggers numbers specified. The time period is defined by a startTime and an endTime.

Inheritance
  • Object
  • Serializable
  • TriggerConfiguration
  • RandomRecurrentTrigger
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

RandomRecurrentTrigger({int minNumberOfTriggers = 0, int maxNumberOfTriggers = 1, TimeOfDay startTime = const TimeOfDay(hour: 8), TimeOfDay endTime = const TimeOfDay(hour: 20)})
Create a RandomRecurrentTrigger.
RandomRecurrentTrigger.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
endTime ↔ TimeOfDay
End time of the day where the trigger can happen.
getter/setter pair
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
lastTriggerTimestamp ↔ DateTime?
The timestamp of when this trigger was triggered last.
getter/setter pair
maxNumberOfTriggers ↔ int
Maximum number of trigger per day.
getter/setter pair
minNumberOfTriggers ↔ int
Minimum number of trigger per day.
getter/setter pair
requiresPrimaryDevice ↔ bool?
Determines whether the trigger needs to be evaluated on a primary device (PrimaryDeviceConfiguration). For example, this is the case when the trigger is time bound and needs to be evaluated by a task scheduler running on a primary device.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDeviceRoleName ↔ String?
The device role name from which the trigger originates.
getter/setter pairinherited
startTime ↔ TimeOfDay
Start time of the day where the trigger can happen.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited