SamplingEventTrigger class

A trigger that resume and pause sampling when some (other) sampling event occurs.

For example, if measureType is dk.cachet.carp.geofence the resumeCondition can be;

  ConditionalEvent({
    'name': 'DTU',
    'type': 'ENTER',
  });
Inheritance
  • Object
  • Serializable
  • Trigger
  • SamplingEventTrigger
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.none, includeIfNull: false)

Constructors

SamplingEventTrigger({required String measureType, ConditionalEvent? resumeCondition, ConditionalEvent? pauseCondition})
Create a trigger that triggers when a measure of measureType is collected, and checks the resumeCondition and pauseCondition to determine if the task should be resumed or paused, respectively.
SamplingEventTrigger.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
measureType ↔ String
The data type of the event to look for.
getter/setter pair
pauseCondition ↔ ConditionalEvent?
The ConditionalEvent specifying a specific sampling value to compare with for pausing this trigger.
getter/setter pair
requiresMasterDevice ↔ bool?
Determines whether the trigger needs to be evaluated on a master device (MasterDeviceDescriptor). For example, this is the case when the trigger is time bound and needs to be evaluated by a task scheduler running on a master device.
getter/setter pairinherited
resumeCondition ↔ ConditionalEvent?
The specific sampling value to compare with for resuming this trigger.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDeviceRoleName ↔ String?
The device role name from which the trigger originates.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited