SmartphoneApplicationData class
Holds application-specific configuration for a SmartphoneStudyProtocol.
- Annotations
-
- @JsonSerializable.new(includeIfNull: false, explicitToJson: true)
Constructors
-
SmartphoneApplicationData({String? applicationName, StudyDescription? studyDescription, DataEndPoint? dataEndPoint, String? privacySchemaName, Map<
String, dynamic> ? applicationData}) -
SmartphoneApplicationData.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
applicationData
↔ Map<
String, dynamic> ? -
Application-specific data to be stored as part of the study protocol
which will be included in all deployments of this study protocol.
getter/setter pair
- applicationName ↔ String?
-
The name of the application which will execute this protocol. This is the
Flutter application name as specified in the pubspec.yaml file of the app
executing this protocol. This is used to filter invitations to studies from
CAWS.
getter/setter pair
- dataEndPoint ↔ DataEndPoint?
-
Specifies where and how to stored or upload the data collected from this
deployment. If
null, the sensed data is not stored, but may still be used in the app.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- privacySchemaName ↔ String?
-
The name of a PrivacySchema.
getter/setter pair
- protocolApiLevel ↔ String?
-
The API level used by this study protocol.
This reflects the version of the CARP Mobile Sensing framework as set in
the pubspec.yaml file.
getter/setter pair
- protocolVersionTag ↔ String?
-
The version tag of the study protocol snapshot.
This is typically set by the CAWS backend when a protocol is uploaded.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- studyDescription ↔ StudyDescription?
-
The description of this study protocol containing the title, description,
purpose, and the responsible researcher for this study.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited