applicationName property

String? applicationName
getter/setter pair

The name of the application which will execute this protocol. This is the Flutter application name as specified in the pubspec.yaml file of the app executing this protocol. This is used to filter invitations to studies from CAWS.

Implementation

String? applicationName;