applicationName property
The name of the application which will execute this protocol.
Implementation
@JsonKey(includeFromJson: false, includeToJson: false)
String? get applicationName => _data.applicationName;
The name of the application which will execute this protocol.
@JsonKey(includeFromJson: false, includeToJson: false)
String? get applicationName => _data.applicationName;