SmartphoneSamplingPackage class abstract

An abstract class for all sampling packages that run on the phone itself.

Note that the default implementation of permissions and onRegister are no-op operations and should hence be overridden in subclasses, if needed.

Inheritance
Implementers

Constructors

SmartphoneSamplingPackage()

Properties

dataTypes → List<DataTypeMetaData>
The list of data type this package supports.
no setteroverride
deviceManager → DeviceManager<DeviceConfiguration<DeviceRegistration>, DeviceRegistration>
Get the DeviceManager for the device used by this package.
no setteroverride
deviceType → String
What device type is this package using?
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingSchemes → DataTypeSamplingSchemeMap
The default sampling schemes for all dataTypes in this package.
no setterinherited

Methods

create(String type) → Probe?
Creates a new Probe of the specified type. Note that type should be one of the dataTypes that this package supports. Returns null if a probe cannot be created for the type.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegister() → void
Callback method when this package is being registered.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited