StudyProtocolManager class abstract

An interface defining a manger of SmartphoneStudyProtocols.

Is mainly used to get and save SmartphoneStudyProtocols. See FileStudyProtocolManager for an example.

Implementers

Constructors

StudyProtocolManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getStudyProtocol(String id) → Future<SmartphoneStudyProtocol?>
Get a SmartphoneStudyProtocol based on its id. Returns null if no protocol exists.
initialize() → void
Initialize the study manager.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveStudyProtocol(String id, SmartphoneStudyProtocol protocol) → Future<bool>
Save a SmartphoneStudyProtocol with the ID id. Returns true if successful, false otherwise.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited