StudyResponsible class

A person who is responsible for a StudyProtocol. Typically the Principal Investigator (PI) who is responsible for the study.

Inheritance
  • Object
  • Serializable
  • StudyResponsible
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

StudyResponsible({required String id, required String name, String? title, String? email, String? affiliation, String? address})
StudyResponsible.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
address ↔ String?
getter/setter pair
affiliation ↔ String?
getter/setter pair
email ↔ String?
getter/setter pair
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited