UserTaskTrigger class

A trigger that triggers based on the state of a UserTask.

Inheritance
  • Object
  • Serializable
  • Trigger
  • UserTaskTrigger
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.none, includeIfNull: false)

Constructors

UserTaskTrigger({required String taskName, required UserTaskState resumeCondition, UserTaskState? pauseCondition})
Create a UserTaskTrigger.
UserTaskTrigger.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
pauseCondition ↔ UserTaskState?
The state of the user task for pausing this trigger.
getter/setter pair
requiresMasterDevice ↔ bool?
Determines whether the trigger needs to be evaluated on a master device (MasterDeviceDescriptor). For example, this is the case when the trigger is time bound and needs to be evaluated by a task scheduler running on a master device.
getter/setter pairinherited
resumeCondition ↔ UserTaskState
The state of the user task for resuming this trigger
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDeviceRoleName ↔ String?
The device role name from which the trigger originates.
getter/setter pairinherited
taskName ↔ String
The name of the task to look for, matching TaskDescriptor.name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited