Flush any buffered data and close this data manager. After calling close the data manager can no longer be used.
@override Future<void> close() async { _flushTimer?.cancel(); await _flush(); await super.close(); }