SQLiteDataManagerFactory class

Implemented types

Constructors

SQLiteDataManagerFactory()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The DataEndPoint type.
no setteroverride

Methods

create() → DataManager
Create a DataManager.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited