Settings class

Handle settings for the CAMS infrastructure. This includes settings for debugging, file paths, and other settings related to the infrastructure layer.

This class is a singleton, access using Settings(). Must be initialized using the init method before used.

Supports:

Constructors

Settings()
factory

Properties

appName → String?
The app name as displayed in the OS. CFBundleDisplayName on iOS, application/android:label on Android.
no setter
buildNumber → String?
The build number. CFBundleVersion on iOS, versionCode on Android.
no setter
carpBasePath → Future<String>
The base path for storing all CARP related files on the form
no setter
debugLevel ↔ DebugLevel
The global debug level setting.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialized → bool
Has the setting been initialized via calling the init method?
no setter
localApplicationPath → Future<String>
Path to a directory where the application may place data that is user-generated.
no setter
packageInfo → PackageInfo?
Package information
no setter
packageName → String?
The package name. PRODUCT_BUNDLE_IDENTIFIER on iOS, package on Android.
no setter
preferences → SharedPreferences?
A simple persistent store for simple data. Note that data is saved in plain format and should hence not be used for sensitive data.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timezone → String
The current time zone of this app.
no setter
userId → Future<String>
Generate a user id that is;
no setter
version → String?
The package version. CFBundleShortVersionString on iOS, versionName on Android.
no setter

Methods

getCacheBasePath(String studyDeploymentId) → Future<String>
The base path for storing all cached data.
getDataBasePath(String studyDeploymentId) → Future<String>
The base path for storing all data (e.g. media files).
getDeploymentBasePath(String studyDeploymentId) → Future<String>
The base path for storing all deployment related files on the form
init() → Future<void>
Initialize settings. Must be called before using any settings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited