timezone property
String
get
timezone
The current time zone of this app.
Note that this is only set once when the app starts, and will not update if the user changes the time zone while the app is running.
Implementation
String get timezone => _timezone;