AbstractDataManager class abstract

An abstract DataManager implementation useful for extension.

Implementers

Constructors

AbstractDataManager()

Properties

controller ↔ StreamController<DataManagerEvent>
getter/setter pair
dataEndPoint → DataEndPoint?
The DataEndPoint that this data manager is handling. Set in the initialize method.
no setter
deployment → SmartphoneDeployment
The deployment using this data manager.
no setteroverride
events → Stream<DataManagerEvent>
Stream of data manager events.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
studyDeploymentId → String
no setter
type → String
The type of this data manager as enumerated in DataEndPointTypes.
no setterinherited

Methods

addEvent(DataManagerEvent event) → void
Add event to the events stream.
close() → Future<void>
Flush any buffered data and close this data manager. After calling close the data manager can no longer be used.
override
initialize(DataEndPoint dataEndPoint, MasterDeviceDeployment deployment, Stream<DataPoint> data) → Future<void>
Initialize the data manager by specifying the dataEndPoint, study deployment, and the stream of data events to handle.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDataPoint(DataPoint dataPoint) → Future<void>
On each data event from the data stream, the onDataPoint handler is called. Implementations of this interface should handle how to save or upload the dataPoint.
inherited
onDone() → Future<void>
When the data stream closes, the onDone handler is called. Default implementation is a no-op function. If another behavior is wanted, implementations of this abstract data manager should handle closing of the data stream.
override
onError(Object? error) → Future<void>
When an error event is send on the stream, the onError handler is called.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited