notificationsEnabled property
bool
get
notificationsEnabled
Should this App Task Controller send notifications to the user.
Implementation
bool get notificationsEnabled => _notificationsEnabled;
Should this App Task Controller send notifications to the user.
bool get notificationsEnabled => _notificationsEnabled;