getSchedule method

  1. @override
List<DateTime> getSchedule(
  1. DateTime from,
  2. DateTime to, [
  3. int? max
])
override

An ordered list of timestamp generated by this trigger for a given period. This is mainly used for persistently scheduling a list of AppTasks from triggers that implement the Schedulable interface.

Implementation

@override
List<DateTime> getSchedule(DateTime from, DateTime to, [int? max]) =>
    (configuration!.schedule.isAfter(from) &&
        configuration!.schedule.isBefore(to))
    ? [configuration!.schedule]
    : [];