deviceType property
String
get
deviceType
The type of the device managed by this device manager
Implementation
String get deviceType => _deviceType;
The type of the device managed by this device manager
String get deviceType => _deviceType;