hasPermissions method

  1. @nonVirtual
Future<bool> hasPermissions()

Does this device manager have the permissions to run?

Note that the result is not cached, since permissions can be revoked in the phone's settings at any time, without the app knowing about it.

Implementation

@nonVirtual
Future<bool> hasPermissions() async {
  return onHasPermissions();
}