onDisconnect abstract method
Callback on disconnect.
This method is called after all sampling on this device has been stopped, and the device manager is trying to disconnect from the real device.
Is to be overridden in sub-classes and implement device-specific disconnection.
Implementation
Future<bool> onDisconnect();