start method

  1. @nonVirtual
void start()

Start sampling of all measures using this device.

This entails that all task control executors using this device are resumed, and hence all data collection for the measures using this device is started.

Implementation

@nonVirtual
void start() {
  info('$runtimeType - Starting sampling...');
  executors.forEach((executor) => executor.resume());
}