DeviceStatus enum

Runtime status for a DeviceManager.

Inheritance
Available extensions

Values

unknown → const DeviceStatus

The state of the device is unknown.

configured → const DeviceStatus

The device manager has been configured, but not yet connected.

paired → const DeviceStatus

The device is paired with this phone. This status is mainly used in Bluetooth devices (via a BLEDeviceManager).

connecting → const DeviceStatus

The phone is trying to connect to the device.

connected → const DeviceStatus

The device is connected to the phone and ready to be used.

reconnected → const DeviceStatus

The device is reconnected after a temporary disconnection, e.g., due to a temporary loss of Bluetooth connection.

disconnecting → const DeviceStatus

The device is temporarily disconnected, e.g., due to a temporary loss of Bluetooth connection, but is expected to be reconnected again.

disconnected → const DeviceStatus

The device is disconnected from the phone.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DeviceStatus>
A constant List of the values in this enum, in order of their declaration.