dispose abstract method

void dispose()

Dispose of this executor.

If not already paused, pause will be called first.

Once disposed, the executor cannot be used anymore and nothing will happen if any of the life cycle methods are called.

Implementation

void dispose();