pauseButShouldBeResumed abstract method
void
pauseButShouldBeResumed()
Pause the executor but mark it to be resumed when possible.
Implementation
void pauseButShouldBeResumed();
Pause the executor but mark it to be resumed when possible.
void pauseButShouldBeResumed();