ExecutorState enum

The state of an Executor.

The runtime state has the following state machine:

+---------------------------------------------------------------+      +-----------+
|  +---------+    +-------------+    +---------+     +--------+ |   -> | undefined |
|  | created | -> | initialized | -> | resumed | <-> | paused | |      +-----------+
|  +---------+    +-------------+    +---------+     +--------+ |   -> | disposed  |
+---------------------------------------------------------------+      +-----------+
Inheritance
Available extensions

Values

Created → const ExecutorState

Created and ready to be initialized.

Initialized → const ExecutorState

Initialized and ready to be resumed.

Resumed → const ExecutorState

Resumed and actively collecting data.

Paused → const ExecutorState

Paused not collecting data. Can be resumed in this state.

PausedButShouldBeResumed → const ExecutorState

Paused and not collecting data, but should be resumed again when possible. This is typically used when a device is disconnected by the OS and the reconnected, and the executor should be resumed again when possible.

Disposed → const ExecutorState

Permanently disposed. Cannot be used anymore.

Undefined → const ExecutorState

Undefined state.

Typically an executor becomes undefined if it cannot be initialized or if this executor (probe) is not supported on the specific phone / OS.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ExecutorState>
A constant List of the values in this enum, in order of their declaration.