PeriodicStreamProbe class abstract
A periodic probe listening on a stream. Listening is done periodically as
specified in a PeriodicSamplingConfiguration listening on intervals every
interval for a period of duration.
During this period, all data are forwarded to this probes measurements stream.
Just like in StreamProbe, sub-classes must implement the
Stream<Measurement>? get stream => ...
method in order to provide the stream to collect data from.
Note that this probe will finish its sampling window even if it is paused. Hence, data can still be generated from this probe, even if paused. Pausing this probe will stop the creation of new collection periods.
- Inheritance
-
- Object
- AbstractExecutor<
Measure> - Probe
- StreamProbe
- PeriodicStreamProbe
- Implementers
Constructors
Properties
- configuration → Measure?
-
The configuration of this executor as set in initialize.
no setterinherited
- deployment → SmartphoneDeployment?
-
The deployment that this executor is part of executing.
no setterinherited
-
deviceManager
↔ DeviceManager<
DeviceConfiguration< DeviceRegistration> , DeviceRegistration> -
The device that this probes uses to collect data.
getter/setter pairinherited
- enabled ↔ bool
-
Is this probe enabled, i.e. available for collection of data using the
resume method.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- measure → Measure?
-
The
Measurethat configures this probe.no setterinherited -
measurements
→ Stream<
Measurement> -
The stream of
Measurementcollected by this executor.no setterinherited -
permissions
→ List<
Permission> -
The list of permissions needed for this probe.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplingConfiguration → PeriodicSamplingConfiguration?
-
The sampling configuration for this probe.
no setteroverride
- samplingState → SamplingState
-
The runtime sampling state of this executor.
no setterinherited
- state → ExecutorState
-
The runtime state of this executor.
no setterinherited
-
stateEvents
→ Stream<
ExecutorState> -
The runtime state changes of this executor.
no setterinherited
-
stream
→ Stream<
Measurement> ? -
The stream of
Measurementobjects for this StreamProbe. Must be implemented by sub-classes.no setterinherited - type → String?
-
The data type this probe is collecting.
no setterinherited
Methods
-
addError(
Object error, [StackTrace? stacktrace]) → void -
Add
errorto the measurements stream.inherited -
addMeasurement(
Measurement measurement) → void -
Add
measurementto the measurements stream.inherited -
arePermissionsGranted(
) → Future< bool> -
Does this probe has the permissions needed to run?
inherited
-
dispose(
) → void -
Dispose of this executor.
inherited
-
error(
) → void -
inherited
-
initialize(
Measure configuration, [SmartphoneDeployment? deployment]) → void -
Configure and initialize the executor before using it.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
) → Future< void> -
Callback when this executor is disposed.
inherited
-
onInitialize(
) → bool -
Callback when this executor is initialized.
Returns true if successfully initialized, false otherwise.
inherited
-
onPause(
) → Future< bool> -
Callback when this executor is paused.
Returns true if successfully paused, false otherwise.
override
-
onResume(
) → Future< bool> -
Callback when this executor is resumed.
Returns true if successfully resumed, false otherwise.
override
-
pause(
) → void -
Pause the executor. Paused until resume is called.
inherited
-
pauseButShouldBeResumed(
) → void -
Pause the executor but mark it to be resumed when possible.
inherited
-
requestPermissions(
) → Future< bool> -
Request the permissions needed for this probe to run.
Return true if all permissions are granted.
Only used on Android - iOS automatically request permissions when
a resource (like the microphone) is accessed.
inherited
-
resume(
) → void -
Resume the executor.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited