SamplingPackage class abstract

Interface for a sampling package.

A sampling package provides information on sampling:

It also contains factory methods for:

  • creating a Probe based on a Measure type
  • creating a DeviceManager based on a device type
Implementers

Constructors

SamplingPackage()

Properties

dataTypes → List<String>
The list of data type this package supports.
no setter
deviceManager → DeviceManager<DeviceRegistration, DeviceDescriptor>
Get the DeviceManager for the device used by this package.
no setter
deviceType → String
What device type is this package using?
no setter
hashCode → int
The hash code for this object.
no setterinherited
permissions → List<Permission>
The list of permissions that this package need.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingSchema → SamplingSchema
The default sampling schema for all dataTypes in this package.
no setter

Methods

create(String type) → Probe?
Creates a new Probe of the specified type. Returns null if a probe cannot be created for this type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegister() → void
Callback method when this package is being registered.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited