SamplingPackageRegistry class

A registry of SamplingPackage packages.

Constructors

SamplingPackageRegistry()
Get the singleton SamplingPackageRegistry.
factory

Properties

dataTypes → List<String>
The combined list of all measure types in all packages.
no setter
hashCode → int
The hash code for this object.
no setterinherited
packages → List<SamplingPackage>
A list of registered packages.
no setter
permissions → List<Permission>
The list of Permission needed for the entire list of packages (combined list).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingSchema → SamplingSchema
The combined sampling schema for all measure types in all packages.
no setter

Methods

create(String type) → Probe?
Create an instance of a probe based on its data type.
lookup(String type) → Set<SamplingPackage>
Lookup the SamplingPackages that support the type of data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(SamplingPackage package) → void
Register a sampling package.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited