addStudy method
Add a study which needs to be executed on this client.
No deployment is attempted yet.
If a study with the same deployment id and device role name has already been added to this client, nothing happens and this study is returned.
Throws NotConfiguredException if the client has not yet been configured. Return the study successfully added to this client manager or the existing study if it was already added.
Implementation
@override
Future<SmartphoneStudy> addStudy(SmartphoneStudy study) async {
await super.addStudy(study);
// Will create a fresh controller, if this is a new study.
getStudyController(study);
info(
'$runtimeType - Adding study, deployment: ${study.deployment?.studyDeploymentId}',
);
notifyListeners();
return study;
}