dataCollectorFactory property

DeviceDataCollectorFactory? get dataCollectorFactory
inherited

Determines which DeviceDataCollector to use to collect data locally on this primary device and this factory is used to create ConnectedDeviceDataCollector instances for connected devices.

Implementation

DeviceDataCollectorFactory? get dataCollectorFactory => _dataCollectorFactory;