getStudyController method

SmartphoneStudyController? getStudyController(
  1. SmartphoneStudy study
)

Get the study controller for a study. If a study controller is not available, a fresh controller will be created.

Implementation

SmartphoneStudyController? getStudyController(SmartphoneStudy study) {
  if (_controllers.containsKey(study)) return _controllers[study];

  // Create a fresh controller and start listening to it.
  final controller = SmartphoneStudyController(study);
  _controllers[study] = controller;
  _group.add(controller.measurements);
  return controller;
}