updateStudy method

  1. @override
void updateStudy(
  1. SmartphoneStudy study
)
override

Update a study which is already stored in the repository. In case study is not stored in this repository, nothing happens.

Implementation

@override
void updateStudy(SmartphoneStudy study) =>
    PersistenceService().updateStudy(study);