SmartphoneDeploymentController class

A SmartphoneDeploymentController controls the execution of a SmartphoneDeployment.

Inheritance
  • Object
  • StudyRuntime
  • SmartphoneDeploymentController

Constructors

SmartphoneDeploymentController(DeploymentService deploymentService, DeviceDataCollectorFactory deviceRegistry)
Create a new SmartphoneDeploymentController to control the runtime behavior of a study deployment.

Properties

data → Stream<DataPoint>
The stream of all sampled data points.
no setter
dataEndPoint → DataEndPoint?
The configuration of the data endpoint, i.e. how data is saved or uploaded.
no setter
dataManager → DataManager?
The data manager responsible for handling the data collected by this controller.
no setter
deployment ↔ SmartphoneDeployment?
The study deployment running in this controller.
getter/setter pairinherited-setteroverride-getter
deploymentService ↔ DeploymentService
The deployment service to use to retrieve and manage the study deployment. Use the initialize method to initialize this service.
getter/setter pairinherited
deploymentStatus ↔ StudyDeploymentStatus
The latest known deployment status.
getter/setter pairinherited
device ↔ MasterDeviceDescriptor?
The description of the device this runtime is intended for within the deployment identified by studyDeploymentId.
getter/setter pairinherited
deviceRegistry ↔ DeviceController
The device registry that handles the devices used in this runtime.
getter/setter pairinherited-setteroverride-getter
deviceRoleName → String?
The device role name.
no setterinherited
executor → StudyDeploymentExecutor?
The executor executing this masterDeployment.
no setter
filename → Future<String?>
Current path and filename of the cached deployment file.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDeployed → bool
Has the device deployment been completed successfully?
no setterinherited
isInitialized → bool
Has this StudyRuntime been initialized?
no setterinherited
isStopped → bool
Has the study and data collection been stopped?
no setterinherited
privacySchemaName → String
The privacy schema used to encrypt data before upload.
no setter
remainingDevicesToRegister → List<DeviceDescriptor>
The list of devices that still remain to be registered before all devices in this study runtime is registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingSize → int
The sampling size of this deployment in terms of number of DataPoint objects that has been collected.
no setter
status ↔ StudyStatus
The status of this StudyRuntime.
getter/setter pairinherited
statusEvents → Stream<StudyStatus>
The stream of StudyStatus events for this controller.
no setterinherited
study → Study?
The study for this study runtime.
no setterinherited
studyDeploymentId → String?
The study deployment id for the study of this controller.
no setterinherited
transformer → DatumTransformer
The datum transformed used to transform data before upload.
no setter

Methods

configure({DataEndPoint? dataEndPoint, String privacySchemaName = NameSpace.CARP, DatumTransformer? transformer}) → Future<void>
Configure this SmartphoneDeploymentController.
dataByType(String type) → Stream<DataPoint>
A stream of all data of a specific data type.
dispose() → void
Called when this StudyRuntime is disposed. This entails stopping and disposing all data sampling and storage.
override
eraseDeployment() → Future<void>
Erase study deployment information cached locally on this phone.
initialize(Study study, DeviceRegistration deviceRegistration) → Future<void>
Initialize this study runtime by specifying its study and deviceRegistration.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
Pause the collection of data for this StudyRuntime.
override
remove() → Future<void>
Remove a study from this SmartphoneDeploymentController.
override
restoreDeployment() → Future<bool>
Restore the deployment from a local file cache. Returns true if successful.
saveDeployment() → Future<bool>
Save the deployment persistently to a file cache. Returns true if successful.
start([bool resume = true]) → void
Start this controller and if resume is true, resume data collection according to the parameters specified in configure.
override
stop() → Future<void>
Permanently stop collecting data for this StudyRuntime.
inherited
toString() → String
A string representation of this object.
inherited
tryDeployment({bool useCached = true}) → Future<StudyStatus>
Verifies whether the master device is ready for deployment and in case it is, deploy the study previously added.
override
tryRegisterConnectedDevice(DeviceDescriptor device) → Future<void>
Tries to register a connected device which are available in this device's deviceRegistry as well as in the deploymentService.
inherited
tryRegisterConnectedDevices() → Future<void>
Tries to register all connected devices which are available in this device's deviceRegistry as well as in the deploymentService.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited