SmartphoneDeploymentExecutor class
A SmartphoneDeploymentExecutor is responsible for executing a SmartphoneDeployment. For each task control in this deployment, it starts a TaskControlExecutor.
Note that the SmartphoneDeploymentExecutor in itself is an Executor and hence work as a 'super executor'. This - amongst other things - imply that you can listen to all collected measurements from the measurements stream and to all state event changes in the stateEvents stream.
- Inheritance
-
- Object
- AbstractExecutor<
SmartphoneDeployment> - AggregateExecutor<
SmartphoneDeployment> - SmartphoneDeploymentExecutor
Constructors
Properties
- configuration → SmartphoneDeployment?
-
The configuration of this executor as set in initialize.
no setterinherited
- deployment → SmartphoneDeployment?
-
The deployment that this executor is part of executing.
no setterinherited
-
executors
→ Set<
Executor> -
The set of underlying executors that this aggregate executor is managing.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
measurements
→ Stream<
Measurement> -
The stream of
Measurementcollected by this executor.no setterinherited -
probes
→ List<
Probe> -
A list of the running probes in this study deployment executor.
May be empty.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplingState → SmartphoneDeploymentExecutorSamplingState
-
The runtime sampling state of this executor.
no setteroverride
- state → ExecutorState
-
The runtime state of this executor.
no setterinherited
-
stateEvents
→ Stream<
ExecutorState> -
The runtime state changes of this executor.
no setterinherited
Methods
-
addError(
Object error, [StackTrace? stacktrace]) → void -
Add
errorto the measurements stream.inherited -
addExecutor(
Executor executor) → void -
Add the
executorto the list of executors and forwards its measurements to this aggregate executor's stream of measurements.inherited -
addMeasurement(
Measurement measurement) → void -
Add
measurementto the measurements stream.inherited -
addMeasurements(
Stream< Measurement> measurements) → void -
Add the stream of
measurementsto the overall stream of measurements for this deployment executor. -
clearSamplingStatus(
) → void - Clear the samplingState of this SmartphoneDeploymentExecutor.
-
dispose(
) → void -
Dispose of this executor.
inherited
-
error(
) → void -
inherited
-
getDeviceManagerFromRoleName(
String? roleName) → DeviceManager< DeviceConfiguration< ?DeviceRegistration> , DeviceRegistration> -
Get the DeviceManager based on the
roleName. This includes both the primary device and the connected devices. Returns null if no device withroleNameis found. -
initialize(
SmartphoneDeployment configuration, [SmartphoneDeployment? deployment]) → void -
Configure and initialize the executor before using it.
inherited
-
lookupProbe(
String type) → List< Probe> -
Lookup all probes of type
type. Returns an empty list if none are found. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
) → Future< void> -
Callback when this executor is disposed.
override
-
onInitialize(
) → bool -
Callback when this executor is initialized.
Returns true if successfully initialized, false otherwise.
override
-
onPause(
) → Future< bool> -
Callback when this executor is paused.
Returns true if successfully paused, false otherwise.
inherited
-
onResume(
) → Future< bool> -
Resumes sampling based on the samplingState of the deployment.
override
-
pause(
) → void -
Pause the executor. Paused until resume is called.
inherited
-
pauseButShouldBeResumed(
) → void -
Pause the executor but mark it to be resumed when possible.
inherited
-
removeExecutor(
Executor executor) → void -
Remove the
executorto the list of executors.inherited -
resume(
) → void -
Resume the executor.
inherited
-
setSamplingState(
SmartphoneDeploymentExecutorSamplingState? samplingState) → void -
Set the
samplingStateof this SmartphoneDeploymentExecutor. This state is used to resume the deployment in the same state as it was before, e.g. after a restart of the app. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited