setSamplingState method

void setSamplingState(
  1. SmartphoneDeploymentExecutorSamplingState? samplingState
)

Set the samplingState of this SmartphoneDeploymentExecutor. This state is used to resume the deployment in the same state as it was before, e.g. after a restart of the app.

Implementation

void setSamplingState(
  SmartphoneDeploymentExecutorSamplingState? samplingState,
) => _samplingState = samplingState;