SmartphoneSamplingPackage class abstract

An abstract class for all sampling packages that run on the phone itself.

Implemented types
Implementers

Constructors

SmartphoneSamplingPackage()

Properties

dataTypes → List<String>
The list of data type this package supports.
no setterinherited
deviceManager → DeviceManager<DeviceRegistration, DeviceDescriptor>
Get the DeviceManager for the device used by this package.
no setteroverride
deviceType → String
What device type is this package using?
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
permissions → List<Permission>
The list of permissions that this package need.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingSchema → SamplingSchema
The default sampling schema for all dataTypes in this package.
no setterinherited

Methods

create(String type) → Probe?
Creates a new Probe of the specified type. Returns null if a probe cannot be created for this type.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegister() → void
Callback method when this package is being registered.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited