dataEndPoint property

DataEndPoint? get dataEndPoint

The configuration of the data endpoint, i.e. how data is saved or uploaded. Can be null, in which case data is still sampled and can be used in the app, but is not saved.

Implementation

DataEndPoint? get dataEndPoint => deployment?.dataEndPoint;