dispose method
Called when this controller is disposed.
This entails:
- pausing data sampling
- closing the data manager (e.g., flushing data to a file)
Note that all cached deployment information and any data sampled from this deployment will remain on the phone.
When this method is called, the controller is never used again. It is an error
to call any of the start or stop methods at this point.
Implementation
@mustCallSuper
void dispose() {
info('$runtimeType - Disposing study from this smartphone...');
pause();
dataManager?.close();
}