remainingDevicesToRegister property

List<DeviceConfiguration<DeviceRegistration>> get remainingDevicesToRegister

The list of all devices - both primary and connected devices - that remain to be registered before all devices in this study are registered.

Returns an empty list if the deployment status is not available yet.

Implementation

List<DeviceConfiguration> get remainingDevicesToRegister =>
    (study.deploymentStatus == null)
    ? []
    : study.deploymentStatus!.deviceStatusList
          .where(
            (deviceStatus) =>
                deviceStatus.status ==
                DeviceDeploymentStatusTypes.Unregistered,
          )
          .map((deviceStatus) => deviceStatus.device)
          .toList();