resume method
void
resume()
Resume data sampling for the study controlled by this controller. Will resume data sampling based on the current sampling state of this study. If you want to restart sampling and ignore any previously stored sampling state, call the restart method instead.
Implementation
void resume() => executor.resume();