TaskControlExecutor class

Responsible for handling the execution of a TaskControl.

This executor runs in real-time and triggers the task using timers. This entails that tasks are only triggered if the app is actively running, either in the foreground or in a background process.

Inheritance
Implementers

Constructors

TaskControlExecutor(TaskControl taskControl, TriggerConfiguration trigger, TaskConfiguration task, DeviceConfiguration<DeviceRegistration> targetDevice)

Properties

configuration → TaskControl?
The configuration of this executor as set in initialize.
no setterinherited
deployment SmartphoneDeployment?
The deployment that this executor is part of executing.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
measurements Stream<Measurement>
The stream of Measurement collected by this executor.
no setteroverride
probes List<Probe>
Returns a list of the running probes in this task control executor.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplingState SamplingState
The runtime sampling state of this executor.
no setteroverride
state ExecutorState
The runtime state of this executor.
no setterinherited
stateEvents Stream<ExecutorState>
The runtime state changes of this executor.
no setterinherited
studyDeploymentId String
no setter
targetDevice → DeviceConfiguration<DeviceRegistration>
no setter
targetDeviceManager DeviceManager<DeviceConfiguration<DeviceRegistration>, DeviceRegistration>?
no setter
task → TaskConfiguration
no setter
taskControl → TaskControl
no setter
taskExecutor TaskExecutor<TaskConfiguration>?
no setter
trigger → TriggerConfiguration
no setter
triggerExecutor TriggerExecutor<TriggerConfiguration>?
no setter

Methods

addError(Object error, [StackTrace? stacktrace]) → void
Add error to the measurements stream.
inherited
addMeasurement(Measurement measurement) → void
Add measurement to the measurements stream.
inherited
dispose() → void
Dispose of this executor.
inherited
error() → void
inherited
initialize(TaskControl configuration, [SmartphoneDeployment? deployment]) → void
Configure and initialize the executor before using it.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() Future<void>
Callback when this executor is disposed.
override
onInitialize() bool
Callback when this executor is initialized. Returns true if successfully initialized, false otherwise.
override
onPause() Future<bool>
Callback when this executor is paused. Returns true if successfully paused, false otherwise.
override
onResume() Future<bool>
Callback when this executor is resumed. Returns true if successfully resumed, false otherwise.
override
onTrigger() → void
Callback when the triggerExecutor triggers.
pause() → void
Pause the executor. Paused until resume is called.
inherited
pauseButShouldBeResumed() → void
Pause the executor but mark it to be resumed when possible.
inherited
resume() → void
Resume the executor.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited