onDispose method
Callback when this executor is disposed.
Subclasses should override this, to implement any cleanup to be done before disposing.
Implementation
@override
@mustCallSuper
Future<void> onDispose() async {
timer?.cancel();
}
Callback when this executor is disposed.
Subclasses should override this, to implement any cleanup to be done before disposing.
@override
@mustCallSuper
Future<void> onDispose() async {
timer?.cancel();
}