timer property
A lot of trigger executors use a timer, so we declare one here to be used by all trigger implementations.
Implementation
Timer? timer;
A lot of trigger executors use a timer, so we declare one here to be used by all trigger implementations.
Timer? timer;