TriggerFactory class abstract

A factory which can create a TriggerExecutor based on the runtime type of an TriggerConfiguration.

Implementers

Constructors

TriggerFactory()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types → Set<Type>
The set of supported TriggerConfiguration runtime types.
no setter

Methods

create(TriggerConfiguration trigger) → TriggerExecutor<TriggerConfiguration>?
Create a TriggerExecutor based on trigger. Returns null if trigger is not supported by this factory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegister() → void
Callback method when this package is being registered.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited