onStart method
Callback from the app when this task is to be started.
Implementation
@mustCallSuper
void onStart() {
// initialize the background task which holds any measures added to the app task
backgroundTaskExecutor.initialize(
task.backgroundTask,
_executor.deployment,
);
state = UserTaskState.started;
}