UserTaskFactory class abstract

A factory which can create a UserTask based on the type of an AppTask.

Implementers

Constructors

UserTaskFactory()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types ↔ List<String>
The list of supported AppTask types.
getter/setter pair

Methods

create(AppTaskExecutor<AppTask> executor) → UserTask
Create a UserTask that wraps executor.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited