sampling_packages library

The sampling package library holds the built-in sampling packages:

Classes

AccelerationFeatures
A set of acceleration (non-gravitational) features collected over a specific sampling period.
AccelerometerFeaturesProbe
A probe collecting accelerometer data over a sampling period and calculates a set of features based on the samplings, as represented by a AccelerationFeatures data point.
AccelerometerProbe
A probe collecting raw data from the accelerometer.
AmbientLight
Ambient light intensity in Lux. Typically collected from the light sensor on the front of the phone.
ApplicationInformation
Holds basic information about the app from where the data is collected.
ApplicationProbe
A probe that collects the device info about this device.
AppLifecycleEvent
Holds information about AppLifecycleState events collected from the phone.
AppLifecycleProbe
A probe that collects app lifecycle events.
BatteryProbe
Collects battery information (charging state and battery level) on a regular basis as specified by the IntervalSamplingConfiguration.interval.
BatteryState
Holds battery level and charging status collected from the phone.
DeviceInformation
Holds basic information about the mobile device from where the data is collected.
DeviceProbe
A probe that collects the device info about this device.
DeviceSamplingPackage
A SamplingPackage containing data types, sampling schemas and probes for collecting information from the device hardware:
FreeMemory
Holds information about free memory on the phone.
GyroscopeProbe
A probe collecting raw data from the gyroscope.
Heartbeat
Reflects a heart beat data send every period minute. Useful for calculating sampling coverage over time.
HeartbeatProbe
A probe that collects heartbeat info about the master device on a regular basis as specified in PeriodicMeasure.frequency.
LightProbe
The LightProbe listens to the phone's light sensor typically located near the front camera. Every value is in the SI unit Lux and is stored in a AmbientLight object.
MagnetometerProbe
A probe collecting raw data from the magnetometer.
MemoryProbe
A probe that collects free virtual memory on a regular basis as specified by the IntervalSamplingConfiguration.interval.
PedometerProbe
The pedometer probe listens to the hardware step counter sensor.
ScreenEvent
Holds a screen event collected from the phone.
ScreenProbe
A probe collecting screen events:
SensorProbe
An abstract sensor probe used by all sensor probes to get the samplingPeriod.
SensorSamplingPackage
A SamplingPackage containing data types, sampling schemas and probes for collecting information from the phone sensors:
StepEvent
Step event data as sensed by the phone's built-in pedometer.
Timezone
Holds timezone information about the mobile device.
TimezoneProbe
A probe that collects the device's current timezone.
UserAccelerometerProbe
A probe collecting raw data from the user accelerometer.