AccelerometerFeaturesProbe class

A probe collecting accelerometer data over a sampling period and calculates a set of features based on the samplings, as represented by a AccelerationFeatures data point.

Configured with a PeriodicSamplingConfiguration configuration.

Inheritance

Properties

bufferingStream Stream
The stream of events to be buffered. Must be specified by sub-classes.
no setteroverride
configuration → Measure?
The configuration of this executor as set in initialize.
no setterinherited
deployment SmartphoneDeployment?
The deployment that this executor is part of executing.
no setterinherited
deviceManager DeviceManager<DeviceConfiguration<DeviceRegistration>, DeviceRegistration>
The device that this probes uses to collect data.
getter/setter pairinherited
enabled bool
Is this probe enabled, i.e. available for collection of data using the resume method.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
measure → Measure?
The Measure that configures this probe.
no setterinherited
measurements Stream<Measurement>
The stream of Measurement collected by this executor.
no setterinherited
permissions List<Permission>
The list of permissions needed for this probe.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplingConfiguration PeriodicSamplingConfiguration?
The sampling configuration for this probe.
no setterinherited
samplingState SamplingState
The runtime sampling state of this executor.
no setterinherited
sensorEndTime int?
getter/setter pair
sensorStartTime int
getter/setter pair
state ExecutorState
The runtime state of this executor.
no setterinherited
stateEvents Stream<ExecutorState>
The runtime state changes of this executor.
no setterinherited
stream Stream<Measurement>
The stream of Measurement objects for this StreamProbe. Must be implemented by sub-classes.
no setterinherited
type String?
The data type this probe is collecting.
no setterinherited
userAccelerometerEventList List<UserAccelerometerEvent>
getter/setter pair

Methods

addError(Object error, [StackTrace? stacktrace]) → void
Add error to the measurements stream.
inherited
addMeasurement(Measurement measurement) → void
Add measurement to the measurements stream.
inherited
arePermissionsGranted() Future<bool>
Does this probe has the permissions needed to run?
inherited
dispose() → void
Dispose of this executor.
inherited
error() → void
inherited
getMeasurement() Future<Measurement?>
Subclasses should implement / override this method to collect the Measurement. This method will be called every time data has been buffered for a duration and should return the final measurement for the buffered data.
override
initialize(Measure configuration, [SmartphoneDeployment? deployment]) → void
Configure and initialize the executor before using it.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() Future<void>
Callback when this executor is disposed.
inherited
onInitialize() bool
Callback when this executor is initialized. Returns true if successfully initialized, false otherwise.
inherited
onPause() Future<bool>
Callback when this executor is paused. Returns true if successfully paused, false otherwise.
inherited
onResume() Future<bool>
Callback when this executor is resumed. Returns true if successfully resumed, false otherwise.
inherited
onSamplingData(dynamic event) → void
Handler for handling onData events from the buffering stream.
override
onSamplingEnd() → void
Handler called when sampling period ends.
override
onSamplingStart() → void
Handler called when sampling period starts.
override
pause() → void
Pause the executor. Paused until resume is called.
inherited
pauseButShouldBeResumed() → void
Pause the executor but mark it to be resumed when possible.
inherited
requestPermissions() Future<bool>
Request the permissions needed for this probe to run. Return true if all permissions are granted. Only used on Android - iOS automatically request permissions when a resource (like the microphone) is accessed.
inherited
resume() → void
Resume the executor.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited