getMeasurement method
Subclasses should implement this method to collect a Measurement.
Can return null if no data is available.
Can return an Error measurement if an error occurs.
Implementation
@override
Future<Measurement?> getMeasurement() async {
if (!Settings().initialized) return null;
return Measurement.fromData(
ApplicationInformation.fromPackageInfo(Settings().packageInfo!),
);
}