BatteryState class

Holds battery level and charging status collected from the phone.

Inheritance
  • Object
  • Serializable
  • Data
  • BatteryState
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

BatteryState([int? batteryLevel, String? batteryStatus])
BatteryState.fromBatteryState(int level, BatteryState state)
BatteryState.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
batteryLevel int?
The battery level in percent.
getter/setter pair
batteryStatus String?
The charging status of the battery:
getter/setter pair
dataType → DataType
The type of this data as a DataType.
no setterinherited
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setteroverride
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
recordId String?
Stable identifier of the source record, if available.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

equivalentTo(Data other) bool
Returns true if the batteryLevel is equal.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override