DeviceInformation class

Holds basic information about the mobile device from where the data is collected.

More information on the data from Android and iOS are available at:

Inheritance
  • Object
  • Serializable
  • Data
  • DeviceInformation
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

DeviceInformation({Map<String, dynamic> deviceData = const {}, String? platform, String? deviceId, String? deviceName, String? deviceModel, String? deviceManufacturer, String? operatingSystem, String? hardware})
DeviceInformation.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
dataType → DataType
The type of this data as a DataType.
no setterinherited
deviceData ↔ Map<String, dynamic>
The full device info for this device.
getter/setter pair
deviceId ↔ String?
An identifier that is unique to the particular device. Note that this ID will change if the user performs a factory reset on their device.
getter/setter pair
deviceManufacturer ↔ String?
Device manufacturer as specified by the OS.
getter/setter pair
deviceModel ↔ String?
Device model as specified by the OS.
getter/setter pair
deviceName ↔ String?
Device name as specified by the OS.
getter/setter pair
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hardware ↔ String?
The hardware type of this device (e.g. 'iPhone7,1' for iPhone 6 Plus).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
operatingSystem ↔ String?
Device OS as specified by the OS.
getter/setter pair
platform ↔ String?
The platform type of the device.
getter/setter pair
recordId → String?
Stable identifier of the source record, if available.
no setterinherited
release ↔ String?
The OS release.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdk ↔ String?
The SDK version.
getter/setter pair

Methods

equivalentTo(Data other) → bool
Returns true if the deviceId is equal.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited