DeviceSamplingPackage class
A SamplingPackage containing data types, sampling schemas and probes for collecting information from the device hardware:
- device info (hardware and operating system information)
- installed app info (name, package name, version, etc.)
- battery level and charging status
- screen events (on/off/unlocked)
- app lifecycle events (inactive, hidden, paused, resumed, detached)
- free memory (physical and virtual)
- local time zone (e.g. "Europe/Copenhagen")
- heartbeat (periodic heartbeat from the device)
- Inheritance
-
- Object
- SamplingPackage
- SmartphoneSamplingPackage
- DeviceSamplingPackage
Constructors
Properties
-
dataTypes
→ List<
DataTypeMetaData> -
The list of data type this package supports.
no setterinherited
-
deviceManager
→ DeviceManager<
DeviceConfiguration< DeviceRegistration> , DeviceRegistration> -
Get the DeviceManager for the device used by this package.
no setterinherited
- deviceType → String
-
What device type is this package using?
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplingSchemes → DataTypeSamplingSchemeMap
-
The default sampling schemes for all dataTypes in this package.
no setteroverride
Methods
-
create(
String type) → Probe? -
Creates a new Probe of the specified
type. Note thattypeshould be one of the dataTypes that this package supports. Returns null if a probe cannot be created for thetype.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onRegister(
) → void -
Callback method when this package is being registered.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- APP_LIFECYCLE_EVENT → const String
- Measure type for app lifecycle state events (inactive, hidden, paused, resumed, detached).
- APPLICATION_INFORMATION → const String
- Measure type for collection of basic application information like app name, package name, version, etc.
- BATTERY_STATE → const String
- Measure type for collection of battery level and charging status.
- DEVICE_INFORMATION → const String
- Measure type for collection of basic device information like device name, model, manufacturer, operating system, and hardware profile.
- FREE_MEMORY → const String
- Measure type for collection of free physical and virtual memory.
- HEARTBEAT → const String
- Collect a heartbeat from the primary device.
- SCREEN_EVENT → const String
- Measure type for collection of screen events (on/off/unlocked).
- TIMEZONE → const String
- Measure type for collection of the time zone of the device. See List of tz database time zones for an overview of timezones.