DEVICE_INFORMATION constant
String
const DEVICE_INFORMATION
Measure type for collection of basic device information like device name, model, manufacturer, operating system, and hardware profile.
- One-time measure.
- Uses the Smartphone primary device for data collection.
- No sampling configuration needed.
Implementation
static const String DEVICE_INFORMATION =
'${CarpDataTypes.CARP_NAMESPACE}.deviceinformation';