Heartbeat class

Reflects a heart beat data send every period minute. Useful for calculating sampling coverage over time.

Inheritance
  • Object
  • Serializable
  • Data
  • Heartbeat
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

Heartbeat({required String deviceType, required String deviceRoleName})
Heartbeat.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
dataType → DataType
The type of this data as a DataType.
no setterinherited
deviceRoleName String
The role name of the device in the protocol.
getter/setter pair
deviceType String
The type of device.
getter/setter pair
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

equivalentTo(Data other) bool
Is this data equivalent to other?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited