ACCELERATION constant
String
const ACCELERATION
Rate of change in velocity, including gravity, along perpendicular x, y, and z axes in the device's coordinate system.
- Event-based measure.
- Uses the Smartphone device for data collection.
- Uses a IntervalSamplingConfiguration sampling configuration.
Implementation
static const String ACCELERATION = CarpDataTypes.ACCELERATION;