NON_GRAVITATIONAL_ACCELERATION constant
String
const NON_GRAVITATIONAL_ACCELERATION
Rate of change in velocity, excluding gravity, along perpendicular x, y, and z axes in the phone's coordinate system.
- Event-based measure.
- Uses the Smartphone device for data collection.
- Uses a IntervalSamplingConfiguration sampling configuration.
Implementation
static const String NON_GRAVITATIONAL_ACCELERATION =
CarpDataTypes.NON_GRAVITATIONAL_ACCELERATION;