STEP_EVENT constant
String
const STEP_EVENT
Step event from the phone's pedometer. Note that this measure type is different from the "stepcount" measure type, which provides aggregated step counts over a time period.
- Event-based measure (one event per step).
- Uses the Smartphone device for data collection.
- No sampling configuration needed.
Implementation
static const String STEP_EVENT = '${CarpDataTypes.CARP_NAMESPACE}.stepevent';