StepEvent class

Step event data as sensed by the phone's built-in pedometer.

Normally, a step event is sent for each step taken by the user. But note that this depends on the underlying OS and hardware capabilities. steps is the number of steps taken since last reboot of the device. This number is accumulated by the OS and not reset when the app is restarted.

Inheritance
  • Object
  • Serializable
  • Data
  • SensorData
  • StepEvent
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

StepEvent({int steps = 0})
StepEvent.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
dataType → DataType
The type of this data as a DataType.
no setterinherited
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorSpecificData ↔ Data?
Additional sensor-specific data pertaining to this data point. This can be used to append highly-specific sensor data to an otherwise common data type.
getter/setter pairinherited
steps int
Number of steps accumulated since last reboot of the device.
getter/setter pair

Methods

equivalentTo(Data other) bool
Is this data equivalent to other?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited