SensorSamplingPackage class

Inheritance

Constructors

SensorSamplingPackage()

Properties

dataTypes → List<String>
The list of data type this package supports.
no setteroverride
deviceManager → DeviceManager<DeviceRegistration, DeviceDescriptor>
Get the DeviceManager for the device used by this package.
no setterinherited
deviceType → String
What device type is this package using?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
permissions → List<Permission>
The list of permissions that this package need.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingSchema → SamplingSchema
Default samplings schema for:
no setteroverride

Methods

create(String type) → Probe?
Creates a new Probe of the specified type. Returns null if a probe cannot be created for this type.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRegister() → void
Callback method when this package is being registered.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

ACCELEROMETER → const String
Measure type for continuos collection of accelerometer data (x,y,z). This includes gravity.
GYROSCOPE → const String
Measure type for continuos collection of gyroscope data (x,y,z).
LIGHT → const String
Measure type for collection of ambient light from the phones light sensor.
MAGNETOMETER → const String
Measure type for continuos collection of magnetometer data (x,y,z).
PEDOMETER → const String
Measure type for collection of step count from the phones pedometer sensor.
PERIODIC_ACCELEROMETER → const String
Measure type for periodic collection of accelerometer data (x,y,z).
PERIODIC_GYROSCOPE → const String
Measure type for periodic collection of gyroscope data (x,y,z).
PERIODIC_MAGNETOMETER → const String
Measure type for periodic collection of magnetometer data (x,y,z).
PERIODIC_USER_ACCELEROMETER → const String
Measure type for periodic collection of user accelerometer data (x,y,z).
USER_ACCELEROMETER → const String
Measure type for continuos collection of user accelerometer data (x,y,z). This excludes gravity.