permissions property
List<Permission>
get
permissions
The list of permissions that are required for this data type.
Note that this is the list of permissions needed for the probe collecting this data type. It should not include permission to access a device itself, such as Bluetooth permissions. Such permissions should be handled on the app level.
See PermissionGroup for a list of possible permissions.
For Android permission in the Manifest.xml file, see Manifest.permission
Declare the Android group; on iOS the Android-only groups are read as
their iOS counterpart (Permission.activityRecognition ->
Permission.sensors, Permission.bluetoothScan -> Permission.bluetooth).
Implementation
List<Permission> get permissions =>
Platform.isIOS ? _permissions.map(_onIOS).toList() : _permissions;
set
permissions
(List<Permission> permissions)
Implementation
set permissions(List<Permission> permissions) => _permissions = permissions;