isConnected property
Indicates whether this device was connected when registered.
Note that a device may be registered when it is not yet connected, e.g., when the device is configured as part of a study deployment, but not yet connected. In this case, the device registration information can be used for connecting the device later on, e.g., when the device is re-connected or when the app is restarted.
Implementation
bool isConnected = false;