configure abstract method
Future<void>
configure({
- required DataEndPoint dataEndPoint,
- required SmartphoneDeployment deployment,
- required Stream<
Measurement> measurements,
Configure the data manager by specifying the study deployment, the
dataEndPoint, and the stream of measurements events to handle.
Implementation
Future<void> configure({
required DataEndPoint dataEndPoint,
required SmartphoneDeployment deployment,
required Stream<Measurement> measurements,
});