executor property
- @JsonKey.new(includeFromJson: false, includeToJson: false)
getter/setter pair
The TriggerExecutor that backs this trigger.
Set automatically by the runtime when the trigger executor is created. Do not set this manually.
Implementation
@JsonKey(includeFromJson: false, includeToJson: false)
/// The [TriggerExecutor] that backs this trigger.
///
/// Set automatically by the runtime when the trigger executor is created.
/// Do not set this manually.
late TriggerExecutor executor;