SmartphoneRegistration class
A DeviceRegistration for a Smartphone specifying details of the phone.
Takes inspiration from the device information available via the device_info_plus via the AndroidDeviceInfo and IosDeviceInfo classes.
- Inheritance
-
- Object
- Serializable
- DeviceRegistration
- CamsDeviceRegistration
- HardwareDeviceRegistration
- SmartphoneRegistration
- Annotations
-
- @JsonSerializable.new(includeIfNull: false, explicitToJson: true)
Constructors
- SmartphoneRegistration({String? deviceId, String? deviceDisplayName, DateTime? registrationCreatedOn, bool isConnected = true, BatteryChargingState batteryChargingState = BatteryChargingState.unknown, String? hardwareName, String? platform, String? deviceName, String? deviceManufacturer, String? deviceModel, String? operatingSystem, String? sdk, String? release})
-
SmartphoneRegistration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $type ↔ String?
-
The runtime class name (type) of this object.
Used for deserialization from JSON objects.
getter/setter pairinherited
- batteryChargingState ↔ BatteryChargingState
-
The battery charging state of the device upon registration.
getter/setter pairinherited
- deviceDisplayName ↔ String?
-
An optional concise textual representation for display purposes describing
the key specifications of the device.
E.g., device manufacturer, name, and operating system version.
getter/setter pairinherited
- deviceId ↔ String
-
An ID for the device, used to disambiguate between devices of the same type,
as provided by the device itself.
It is up to specific types of devices to guarantee uniqueness across all
devices of the same type.
getter/setter pairinherited
- deviceManufacturer ↔ String?
-
Device manufacturer as specified by the OS.
getter/setter pair
- deviceModel ↔ String?
-
Device model as specified by the OS.
getter/setter pair
- deviceName ↔ String?
-
Device name as specified by the OS.
getter/setter pair
- fromJsonFunction → Function
-
The function which can convert a JSON string to an object of this type.
no setteroverride
- hardware ↔ String?
-
The hardware type of this device (e.g. 'iPhone7,1' for iPhone 6 Plus).
getter/setter pair
- hardwareName ↔ String?
-
The hardware name of this device, if available.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected ↔ bool
-
Indicates whether this device was connected when registered.
getter/setter pairinherited
- jsonType → String
-
Return the
__typeto be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.no setterinherited - operatingSystem ↔ String?
-
Device OS as specified by the OS.
getter/setter pair
- platform ↔ String?
-
The platform type of the device - Android or iOS.
getter/setter pair
- registrationCreatedOn ↔ DateTime
-
The registration time in zulu time.
getter/setter pairinherited
- release ↔ String?
-
The OS release.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdk ↔ String?
-
The SDK version.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Return a JSON encoding of this object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited