SmartphoneStudyStatusEvent class

An event related to a running study, including its runtime state.

Inheritance

Constructors

SmartphoneStudyStatusEvent(SmartphoneStudy study, StudyStatusEventTypes event, [SmartphoneDeploymentExecutorSamplingState? state])
const

Properties

event → StudyStatusEventTypes
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state SmartphoneDeploymentExecutorSamplingState?
final
study SmartphoneStudy
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited