AbstractExecutor<TConfig> class
abstract
An abstract implementation of a Executor to extend from.
- Implemented types
-
- Executor<
TConfig>
- Executor<
- Implementers
Constructors
Properties
- configuration → TConfig?
-
The configuration of this executor as set in initialize.
no setteroverride
- deployment → SmartphoneDeployment?
-
The deployment that this executor is part of executing.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
measurements
→ Stream<
Measurement> -
The stream of
Measurementcollected by this executor.no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplingState → SamplingState
-
The runtime sampling state of this executor.
no setteroverride
- state → ExecutorState
-
The runtime state of this executor.
no setteroverride
-
stateEvents
→ Stream<
ExecutorState> -
The runtime state changes of this executor.
no setteroverride
Methods
-
addError(
Object error, [StackTrace? stacktrace]) → void -
Add
errorto the measurements stream. -
addMeasurement(
Measurement measurement) → void -
Add
measurementto the measurements stream. -
dispose(
) → void -
Dispose of this executor.
override
-
error(
) → void -
initialize(
TConfig configuration, [SmartphoneDeployment? deployment]) → void -
Configure and initialize the executor before using it.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
) → Future< void> - Callback when this executor is disposed.
-
onInitialize(
) → bool - Callback when this executor is initialized. Returns true if successfully initialized, false otherwise.
-
onPause(
) → Future< bool> - Callback when this executor is paused. Returns true if successfully paused, false otherwise.
-
onResume(
) → Future< bool> - Callback when this executor is resumed. Returns true if successfully resumed, false otherwise.
-
pause(
) → void -
Pause the executor. Paused until resume is called.
override
-
pauseButShouldBeResumed(
) → void -
Pause the executor but mark it to be resumed when possible.
override
-
resume(
) → void -
Resume the executor.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited