AppTaskControlExecutor class
Responsible for handling the execution of a TaskControl which contains
an AppTask.
In contrast to the TaskControlExecutor (which runs in the background),
this AppTaskControlExecutor will try to schedule the AppTask using
the AppTaskController. This means that the trigger has to be
Schedulable.
- Inheritance
-
- Object
- AbstractExecutor<
TaskControl> - TaskControlExecutor
- AppTaskControlExecutor
Constructors
-
AppTaskControlExecutor(TaskControl taskControl, TriggerConfiguration trigger, TaskConfiguration task, DeviceConfiguration<
DeviceRegistration> targetDevice)
Properties
- configuration → TaskControl?
-
The configuration of this executor as set in initialize.
no setterinherited
- deployment → SmartphoneDeployment?
-
The deployment that this executor is part of executing.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
measurements
→ Stream<
Measurement> -
The stream of
Measurementcollected by this executor.no setterinherited -
probes
→ List<
Probe> -
Returns a list of the running probes in this task control executor.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplingState → SamplingState
-
The runtime sampling state of this executor.
no setterinherited
- state → ExecutorState
-
The runtime state of this executor.
no setterinherited
-
stateEvents
→ Stream<
ExecutorState> -
The runtime state changes of this executor.
no setterinherited
- studyDeploymentId → String
-
no setterinherited
-
targetDevice
→ DeviceConfiguration<
DeviceRegistration> -
no setterinherited
-
targetDeviceManager
→ DeviceManager<
DeviceConfiguration< ?DeviceRegistration> , DeviceRegistration> -
no setterinherited
- task → TaskConfiguration
-
no setterinherited
- taskControl → TaskControl
-
no setterinherited
-
taskExecutor
→ AppTaskExecutor<
AppTask> -
no setteroverride
- trigger → TriggerConfiguration
-
no setterinherited
-
triggerExecutor
→ SchedulableTriggerExecutor<
TriggerConfiguration> -
no setteroverride
Methods
-
addError(
Object error, [StackTrace? stacktrace]) → void -
Add
errorto the measurements stream.inherited -
addMeasurement(
Measurement measurement) → void -
Add
measurementto the measurements stream.inherited -
dispose(
) → void -
Dispose of this executor.
inherited
-
error(
) → void -
inherited
-
initialize(
TaskControl configuration, [SmartphoneDeployment? deployment]) → void -
Configure and initialize the executor before using it.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
) → Future< void> -
Callback when this executor is disposed.
inherited
-
onInitialize(
) → bool -
Callback when this executor is initialized.
Returns true if successfully initialized, false otherwise.
inherited
-
onPause(
) → Future< bool> -
Callback when this executor is paused.
Returns true if successfully paused, false otherwise.
override
-
onResume(
) → Future< bool> -
Callback when this executor is resumed.
Returns true if successfully resumed, false otherwise.
override
-
onTrigger(
) → void -
Callback when the triggerExecutor triggers.
inherited
-
pause(
) → void -
Pause the executor. Paused until resume is called.
inherited
-
pauseButShouldBeResumed(
) → void -
Pause the executor but mark it to be resumed when possible.
inherited
-
resume(
) → void -
Resume the executor.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited