onPaired method
Implementation
// By default, pairing is successful, but can be overridden in sub-classes
// for device-specific pairing handling.
/// Called by the [pair] method after setting the BLE device information.
bool onPaired() => true;
// By default, pairing is successful, but can be overridden in sub-classes
// for device-specific pairing handling.
/// Called by the [pair] method after setting the BLE device information.
bool onPaired() => true;