onConfigure abstract method
void
onConfigure()
Callback on configure.
When called, the configuration and the registration is available.
Is to be overridden in sub-classes. Note, however, that it must not be doing a lot of work on startup.
Implementation
void onConfigure();