registration property
TRegistration?
get
registration
The latest registration for this device.
Is set using the configure method and contains the latest registered runtime information about the real device, e.g., the BLE address of a Bluetooth device.
Implementation
TRegistration? get registration => _registration;