shouldConnect property
bool
get
shouldConnect
Indicates whether this device manager should connect to the real device based on the last known registration information. Returns true (default) if no prior registration information is available,
Implementation
bool get shouldConnect => registration is CamsDeviceRegistration
? (registration as CamsDeviceRegistration).isConnected
: true;