FunctionTaskExecutor class
Executes a FunctionTask.
- Inheritance
-
- Object
- AbstractExecutor<
FunctionTask> - AggregateExecutor<
FunctionTask> - TaskExecutor<
FunctionTask> - FunctionTaskExecutor
Constructors
Properties
- configuration → FunctionTask?
-
The configuration of this executor as set in initialize.
no setterinherited
- deployment → SmartphoneDeployment?
-
The deployment that this executor is part of executing.
no setterinherited
-
executors
→ Set<
Executor> -
The set of underlying executors that this aggregate executor is managing.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
measurements
→ Stream<
Measurement> -
The stream of
Measurementcollected by this executor.no setterinherited -
probes
→ List<
Probe> -
Returns a list of the probes in this task executor.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplingState → SamplingState
-
The runtime sampling state of this executor.
no setterinherited
- state → ExecutorState
-
The runtime state of this executor.
no setterinherited
-
stateEvents
→ Stream<
ExecutorState> -
The runtime state changes of this executor.
no setterinherited
-
states
→ Stream<
ExecutorState> -
The combines state event from all probes in this task executor.
no setterinherited
- task → FunctionTask
-
The
TaskConfigurationfor this task executor.no setterinherited
Methods
-
addError(
Object error, [StackTrace? stacktrace]) → void -
Add
errorto the measurements stream.inherited -
addExecutor(
Executor executor) → void -
Add the
executorto the list of executors and forwards its measurements to this aggregate executor's stream of measurements.inherited -
addMeasurement(
Measurement measurement) → void -
Add
measurementto the measurements stream.inherited -
dispose(
) → void -
Dispose of this executor.
inherited
-
error(
) → void -
inherited
-
initialize(
FunctionTask configuration, [SmartphoneDeployment? deployment]) → void -
Configure and initialize the executor before using it.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
) → Future< void> -
Callback when this executor is disposed.
inherited
-
onInitialize(
) → bool -
Callback when this executor is initialized.
Returns true if successfully initialized, false otherwise.
override
-
onPause(
) → Future< bool> -
Callback when this executor is paused.
Returns true if successfully paused, false otherwise.
inherited
-
onResume(
) → Future< bool> -
Callback when this executor is resumed.
Returns true if successfully resumed, false otherwise.
override
-
pause(
) → void -
Pause the executor. Paused until resume is called.
inherited
-
pauseButShouldBeResumed(
) → void -
Pause the executor but mark it to be resumed when possible.
inherited
-
removeExecutor(
Executor executor) → void -
Remove the
executorto the list of executors.inherited -
resume(
) → void -
Resume the executor.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited