RandomRecurrentTriggerExecutor class

Executes a RandomRecurrentTrigger triggering N times per day within a defined period of time.

Inheritance

Properties

configuration RandomRecurrentTrigger?
The configuration of this executor as set in initialize.
no setterinherited
deployment SmartphoneDeployment?
The deployment that this executor is part of executing.
no setterinherited
endTime → TimeOfDay
no setter
hasBeenScheduledForToday bool
no setter
hashCode int
The hash code for this object.
no setterinherited
maxNumberOfTriggers int
no setter
measurements Stream<Measurement>
The stream of Measurement collected by this executor.
no setterinherited
minNumberOfTriggers int
no setter
numberOfSampling int
Get a random number of samples for the day
no setter
randomTime → TimeOfDay
Get a random time between startTime and endTime
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplingState SamplingState
The runtime sampling state of this executor.
no setterinherited
samplingTimes List<TimeOfDay>
Get N random times between startTime and endTime
no setter
startTime → TimeOfDay
no setter
state ExecutorState
The runtime state of this executor.
no setterinherited
stateEvents Stream<ExecutorState>
The runtime state changes of this executor.
no setterinherited
timer Timer?
A lot of trigger executors use a timer, so we declare one here to be used by all trigger implementations.
getter/setter pairinherited
todayString String
no setter
triggerEvents Stream<TriggerEvent>
The stream of events triggered from this trigger executor.
no setterinherited

Methods

addError(Object error, [StackTrace? stacktrace]) → void
Add error to the measurements stream.
inherited
addMeasurement(Measurement measurement) → void
Add measurement to the measurements stream.
inherited
dispose() → void
Dispose of this executor.
inherited
error() → void
inherited
getSchedule(DateTime from, DateTime to, [int max = 100]) List<DateTime>
An ordered list of timestamp generated by this trigger for a given period. This is mainly used for persistently scheduling a list of AppTasks from triggers that implement the Schedulable interface.
override
initialize(RandomRecurrentTrigger configuration, [SmartphoneDeployment? deployment]) → void
Configure and initialize the executor before using it.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() Future<void>
Callback when this executor is disposed.
inherited
onInitialize() bool
Callback when this executor is initialized. Returns true if successfully initialized, false otherwise.
inherited
onPause() Future<bool>
Callback when this executor is paused. Returns true if successfully paused, false otherwise.
inherited
onResume() Future<bool>
Callback when this executor is resumed. Returns true if successfully resumed, false otherwise.
override
onTrigger() → void
Called when this trigger executor is triggering.
inherited
pause() → void
Pause the executor. Paused until resume is called.
inherited
pauseButShouldBeResumed() → void
Pause the executor but mark it to be resumed when possible.
inherited
resume() → void
Resume the executor.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited