getStudyDeploymentStatus method
Get the deployment status for the study from the deployment service.
This updates the study's deployment status and sets the study's status
accordingly.
Returns null if the deployment status could not be retrieved from the
deployment service or if the study has not been added to this client manager.
Implementation
@mustCallSuper
Future<StudyDeploymentStatus?> getStudyDeploymentStatus(TStudy study) async {
_checkConfiguration();
if (repository.hasStudy(study)) {
return await proxy?.getStudyDeploymentStatus(study);
}
return null;
}