removeStudy method
Remove study which is already stored in the repository.
In case study is not stored in this repository, nothing happens.
Implementation
@override
void removeStudy(SmartphoneStudy study) {
_studyStatusEventGroup.remove(study.events);
_repository.remove(study);
PersistenceService().removeStudy(study);
}