tryRegisterRemainingDevicesToRegister method
Tries to register the connected devices which still need to be registered in the deployment service.
This is a convenient method for synchronizing the devices needed for a deployment and the available devices on this phone.
Implementation
Future<void> tryRegisterRemainingDevicesToRegister() async =>
remainingDevicesToRegister.forEach((device) async {
await tryRegisterConnectedDevice(device);
});