AppLifecycleProbe class
A probe that collects app lifecycle events.
- Inheritance
-
- Object
- AbstractExecutor<
Measure> - Probe
- StreamProbe
- AppLifecycleProbe
- Mixed-in types
Constructors
Properties
- configuration → Measure?
-
The configuration of this executor as set in initialize.
no setterinherited
- deployment → SmartphoneDeployment?
-
The deployment that this executor is part of executing.
no setterinherited
-
deviceManager
↔ DeviceManager<
DeviceConfiguration< DeviceRegistration> , DeviceRegistration> -
The device that this probes uses to collect data.
getter/setter pairinherited
- enabled ↔ bool
-
Is this probe enabled, i.e. available for collection of data using the
resume method.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- measure → Measure?
-
The
Measurethat configures this probe.no setterinherited -
measurements
→ Stream<
Measurement> -
The stream of
Measurementcollected by this executor.no setterinherited -
permissions
→ List<
Permission> -
The list of permissions needed for this probe.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplingConfiguration → SamplingConfiguration?
-
The sampling configuration for this probe.
no setterinherited
- samplingState → SamplingState
-
The runtime sampling state of this executor.
no setterinherited
- state → ExecutorState
-
The runtime state of this executor.
no setterinherited
-
stateEvents
→ Stream<
ExecutorState> -
The runtime state changes of this executor.
no setterinherited
-
stream
→ Stream<
Measurement> -
The stream of
Measurementobjects for this StreamProbe. Must be implemented by sub-classes.no setteroverride - type → String?
-
The data type this probe is collecting.
no setterinherited
Methods
-
addError(
Object error, [StackTrace? stacktrace]) → void -
Add
errorto the measurements stream.inherited -
addMeasurement(
Measurement measurement) → void -
Add
measurementto the measurements stream.inherited -
arePermissionsGranted(
) → Future< bool> -
Does this probe has the permissions needed to run?
inherited
-
didChangeAccessibilityFeatures(
) → void -
Called when the system changes the set of currently active accessibility
features.
inherited
-
didChangeAppLifecycleState(
AppLifecycleState state) → void -
Called when the system puts the app in the background or returns
the app to the foreground.
override
-
didChangeLocales(
List< Locale> ? locales) → void -
Called when the system tells the app that the user's locale has
changed. For example, if the user changes the system language
settings.
inherited
-
didChangeMetrics(
) → void -
Called when the application's dimensions change. For example,
when a phone is rotated.
inherited
-
didChangePlatformBrightness(
) → void -
Called when the platform brightness changes.
inherited
-
didChangeTextScaleFactor(
) → void -
Called when the platform's text scale factor changes.
inherited
-
didChangeViewFocus(
ViewFocusEvent event) → void -
Called whenever the PlatformDispatcher receives a notification that the
focus state on a view has changed.
inherited
-
didHaveMemoryPressure(
) → void -
Called when the system is running low on memory.
inherited
-
didPopRoute(
) → Future< bool> -
Called when the system tells the app to pop the current route, such as
after a system back button press or back gesture.
inherited
-
didPushRoute(
String route) → Future< bool> -
Called when the host tells the application to push a new route onto the
navigator.
inherited
-
didPushRouteInformation(
RouteInformation routeInformation) → Future< bool> -
Called when the host tells the application to push a new
RouteInformation and a restoration state onto the router.
inherited
-
didRequestAppExit(
) → Future< AppExitResponse> -
Called when a request is received from the system to exit the application.
inherited
-
dispose(
) → void -
Dispose of this executor.
inherited
-
error(
) → void -
inherited
-
handleCancelBackGesture(
) → void -
Called when a predictive back gesture is canceled, indicating that no
navigation should occur.
inherited
-
handleCommitBackGesture(
) → void -
Called when a predictive back gesture is finished successfully, indicating
that the current route should be popped.
inherited
-
handleStartBackGesture(
PredictiveBackEvent backEvent) → bool -
Called at the start of a predictive back gesture.
inherited
-
handleStatusBarTap(
) → void -
Called when the user taps the status bar on iOS, to scroll a scroll
view to the top.
inherited
-
handleUpdateBackGestureProgress(
PredictiveBackEvent backEvent) → void -
Called when a predictive back gesture moves.
inherited
-
initialize(
Measure configuration, [SmartphoneDeployment? deployment]) → void -
Configure and initialize the executor before using it.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
) → Future< void> -
Callback when this executor is disposed.
inherited
-
onInitialize(
) → bool -
Callback when this executor is initialized.
Returns true if successfully initialized, false otherwise.
inherited
-
onPause(
) → Future< bool> -
Callback when this executor is paused.
Returns true if successfully paused, false otherwise.
override
-
onResume(
) → Future< bool> -
Callback when this executor is resumed.
Returns true if successfully resumed, false otherwise.
override
-
pause(
) → void -
Pause the executor. Paused until resume is called.
inherited
-
pauseButShouldBeResumed(
) → void -
Pause the executor but mark it to be resumed when possible.
inherited
-
requestPermissions(
) → Future< bool> -
Request the permissions needed for this probe to run.
Return true if all permissions are granted.
Only used on Android - iOS automatically request permissions when
a resource (like the microphone) is accessed.
inherited
-
resume(
) → void -
Resume the executor.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited