ApplicationInformation class
Holds basic information about the app from where the data is collected.
Uses the same data structure as the package_info_plus package.
- Inheritance
-
- Object
- Serializable
- Data
- ApplicationInformation
- Annotations
-
- @JsonSerializable.new(includeIfNull: false, explicitToJson: true)
Constructors
- ApplicationInformation({required String appName, required String packageName, required String version, required String buildNumber, String buildSignature = '', String? installerStore, DateTime? installTime, DateTime? updateTime})
-
ApplicationInformation.fromJson(Map<
String, dynamic> json) -
factory
- ApplicationInformation.fromPackageInfo(PackageInfo info)
Properties
- $type ↔ String?
-
The runtime class name (type) of this object.
Used for deserialization from JSON objects.
getter/setter pairinherited
- appName → String
-
The app name.
final
- buildNumber → String
-
The build number.
Generated from the version in
pubspec.yaml.final - buildSignature → String
-
The build signature.
SHA-256 signing key signature (hex) on Android.
Empty string on iOS.
final
- dataType → DataType
-
The type of this data as a
DataType.no setterinherited - fromJsonFunction → Function
-
The function which can convert a JSON string to an object of this type.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- installerStore → String?
-
The installer store. Indicates through which store this application was installed.
final
- installTime → DateTime?
-
The time when the application was installed.
final
- jsonType → String
-
Return the
__typeto be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.no setterinherited - packageName → String
-
The package name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateTime → DateTime?
-
The time when the application was last updated.
final
- version → String
-
The package version.
Generated from the version in
pubspec.yaml.final
Methods
-
equivalentTo(
Data other) → bool -
Returns
trueif the appName is equal.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Return a JSON encoding of this object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited